==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkBinCellDataFilter.java <==
// java wrapper for vtkBinCellDataFilter object
//

package vtk;
import vtk.*;

public class vtkBinCellDataFilter extends vtkDataSetAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfBins_4(int id0);
  public void SetNumberOfBins(int id0)
    { SetNumberOfBins_4(id0); }

  private native int GetNumberOfBins_5();
  public int GetNumberOfBins()
    { return GetNumberOfBins_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native void SetSourceData_8(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_8(id0); }

  private native long GetSource_9();
  public vtkDataObject GetSource() {
    long temp = GetSource_9();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSourceConnection_10(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_10(id0); }

  private native void SetSpatialMatch_11(int id0);
  public void SetSpatialMatch(int id0)
    { SetSpatialMatch_11(id0); }

  private native int GetSpatialMatch_12();
  public int GetSpatialMatch()
    { return GetSpatialMatch_12(); }

  private native void SpatialMatchOn_13();
  public void SpatialMatchOn()
    { SpatialMatchOn_13(); }

  private native void SpatialMatchOff_14();
  public void SpatialMatchOff()
    { SpatialMatchOff_14(); }

  private native void SetStoreNumberOfNonzeroBins_15(boolean id0);
  public void SetStoreNumberOfNonzeroBins(boolean id0)
    { SetStoreNumberOfNonzeroBins_15(id0); }

  private native void StoreNumberOfNonzeroBinsOn_16();
  public void StoreNumberOfNonzeroBinsOn()
    { StoreNumberOfNonzeroBinsOn_16(); }

  private native void StoreNumberOfNonzeroBinsOff_17();
  public void StoreNumberOfNonzeroBinsOff()
    { StoreNumberOfNonzeroBinsOff_17(); }

  private native boolean GetStoreNumberOfNonzeroBins_18();
  public boolean GetStoreNumberOfNonzeroBins()
    { return GetStoreNumberOfNonzeroBins_18(); }

  private native void SetNumberOfNonzeroBinsArrayName_19(String id0);
  public void SetNumberOfNonzeroBinsArrayName(String id0)
    { SetNumberOfNonzeroBinsArrayName_19(id0); }

  private native String GetNumberOfNonzeroBinsArrayName_20();
  public String GetNumberOfNonzeroBinsArrayName()
    { return GetNumberOfNonzeroBinsArrayName_20(); }

  private native void SetTolerance_21(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_21(id0); }

  private native double GetTolerance_22();
  public double GetTolerance()
    { return GetTolerance_22(); }

  private native void SetComputeTolerance_23(boolean id0);
  public void SetComputeTolerance(boolean id0)
    { SetComputeTolerance_23(id0); }

  private native void ComputeToleranceOn_24();
  public void ComputeToleranceOn()
    { ComputeToleranceOn_24(); }

  private native void ComputeToleranceOff_25();
  public void ComputeToleranceOff()
    { ComputeToleranceOff_25(); }

  private native boolean GetComputeTolerance_26();
  public boolean GetComputeTolerance()
    { return GetComputeTolerance_26(); }

  private native void SetArrayComponent_27(int id0);
  public void SetArrayComponent(int id0)
    { SetArrayComponent_27(id0); }

  private native int GetArrayComponent_28();
  public int GetArrayComponent()
    { return GetArrayComponent_28(); }

  private native void SetCellOverlapMethod_29(int id0);
  public void SetCellOverlapMethod(int id0)
    { SetCellOverlapMethod_29(id0); }

  private native int GetCellOverlapMethodMinValue_30();
  public int GetCellOverlapMethodMinValue()
    { return GetCellOverlapMethodMinValue_30(); }

  private native int GetCellOverlapMethodMaxValue_31();
  public int GetCellOverlapMethodMaxValue()
    { return GetCellOverlapMethodMaxValue_31(); }

  private native int GetCellOverlapMethod_32();
  public int GetCellOverlapMethod()
    { return GetCellOverlapMethod_32(); }

  private native void SetCellLocator_33(vtkCellLocator id0);
  public void SetCellLocator(vtkCellLocator id0)
    { SetCellLocator_33(id0); }

  private native long GetCellLocator_34();
  public vtkCellLocator GetCellLocator() {
    long temp = GetCellLocator_34();

    if (temp == 0) return null;
    return (vtkCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkBinCellDataFilter() { super(); }

  public vtkBinCellDataFilter(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.1-2-armv7h.pkg.tar.xz: vtk/vtkBinCellDataFilter.java <==
// java wrapper for vtkBinCellDataFilter object
//

package vtk;
import vtk.*;

public class vtkBinCellDataFilter extends vtkDataSetAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetValue_2(int id0,double id1);
  public void SetValue(int id0,double id1)
    { SetValue_2(id0,id1); }

  private native double GetValue_3(int id0);
  public double GetValue(int id0)
    { return GetValue_3(id0); }

  private native void SetNumberOfBins_4(int id0);
  public void SetNumberOfBins(int id0)
    { SetNumberOfBins_4(id0); }

  private native int GetNumberOfBins_5();
  public int GetNumberOfBins()
    { return GetNumberOfBins_5(); }

  private native void GenerateValues_6(int id0,double id1[]);
  public void GenerateValues(int id0,double id1[])
    { GenerateValues_6(id0,id1); }

  private native void GenerateValues_7(int id0,double id1,double id2);
  public void GenerateValues(int id0,double id1,double id2)
    { GenerateValues_7(id0,id1,id2); }

  private native void SetSourceData_8(vtkDataObject id0);
  public void SetSourceData(vtkDataObject id0)
    { SetSourceData_8(id0); }

  private native long GetSource_9();
  public vtkDataObject GetSource() {
    long temp = GetSource_9();

    if (temp == 0) return null;
    return (vtkDataObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSourceConnection_10(vtkAlgorithmOutput id0);
  public void SetSourceConnection(vtkAlgorithmOutput id0)
    { SetSourceConnection_10(id0); }

  private native void SetSpatialMatch_11(int id0);
  public void SetSpatialMatch(int id0)
    { SetSpatialMatch_11(id0); }

  private native int GetSpatialMatch_12();
  public int GetSpatialMatch()
    { return GetSpatialMatch_12(); }

  private native void SpatialMatchOn_13();
  public void SpatialMatchOn()
    { SpatialMatchOn_13(); }

  private native void SpatialMatchOff_14();
  public void SpatialMatchOff()
    { SpatialMatchOff_14(); }

  private native void SetStoreNumberOfNonzeroBins_15(boolean id0);
  public void SetStoreNumberOfNonzeroBins(boolean id0)
    { SetStoreNumberOfNonzeroBins_15(id0); }

  private native void StoreNumberOfNonzeroBinsOn_16();
  public void StoreNumberOfNonzeroBinsOn()
    { StoreNumberOfNonzeroBinsOn_16(); }

  private native void StoreNumberOfNonzeroBinsOff_17();
  public void StoreNumberOfNonzeroBinsOff()
    { StoreNumberOfNonzeroBinsOff_17(); }

  private native boolean GetStoreNumberOfNonzeroBins_18();
  public boolean GetStoreNumberOfNonzeroBins()
    { return GetStoreNumberOfNonzeroBins_18(); }

  private native void SetNumberOfNonzeroBinsArrayName_19(String id0);
  public void SetNumberOfNonzeroBinsArrayName(String id0)
    { SetNumberOfNonzeroBinsArrayName_19(id0); }

  private native String GetNumberOfNonzeroBinsArrayName_20();
  public String GetNumberOfNonzeroBinsArrayName()
    { return GetNumberOfNonzeroBinsArrayName_20(); }

  private native void SetTolerance_21(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_21(id0); }

  private native double GetTolerance_22();
  public double GetTolerance()
    { return GetTolerance_22(); }

  private native void SetComputeTolerance_23(boolean id0);
  public void SetComputeTolerance(boolean id0)
    { SetComputeTolerance_23(id0); }

  private native void ComputeToleranceOn_24();
  public void ComputeToleranceOn()
    { ComputeToleranceOn_24(); }

  private native void ComputeToleranceOff_25();
  public void ComputeToleranceOff()
    { ComputeToleranceOff_25(); }

  private native boolean GetComputeTolerance_26();
  public boolean GetComputeTolerance()
    { return GetComputeTolerance_26(); }

  private native void SetArrayComponent_27(int id0);
  public void SetArrayComponent(int id0)
    { SetArrayComponent_27(id0); }

  private native int GetArrayComponent_28();
  public int GetArrayComponent()
    { return GetArrayComponent_28(); }

  private native void SetCellOverlapMethod_29(int id0);
  public void SetCellOverlapMethod(int id0)
    { SetCellOverlapMethod_29(id0); }

  private native int GetCellOverlapMethodMinValue_30();
  public int GetCellOverlapMethodMinValue()
    { return GetCellOverlapMethodMinValue_30(); }

  private native int GetCellOverlapMethodMaxValue_31();
  public int GetCellOverlapMethodMaxValue()
    { return GetCellOverlapMethodMaxValue_31(); }

  private native int GetCellOverlapMethod_32();
  public int GetCellOverlapMethod()
    { return GetCellOverlapMethod_32(); }

  private native void SetCellLocator_33(vtkCellLocator id0);
  public void SetCellLocator(vtkCellLocator id0)
    { SetCellLocator_33(id0); }

  private native long GetCellLocator_34();
  public vtkCellLocator GetCellLocator() {
    long temp = GetCellLocator_34();

    if (temp == 0) return null;
    return (vtkCellLocator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkBinCellDataFilter() { super(); }

  public vtkBinCellDataFilter(long id) { super(id); }
  public native long   VTKInit();

}
